
---
layout: ""
page_title: "Provider: IOSXE"
description: |-
  The IOSXE provider provides resources to interact with one or more Cisco IOS-XE devices.
---

# IOSXE Provider

The IOSXE provider provides resources to interact with one or more Cisco IOS-XE devices.

It communicates with IOS-XE devices via the RESTCONF API, which requires the following device configuration.

```
ip http secure-server
restconf
```

## Example Usage

```terraform
provider "iosxe" {
  username = "admin"
  password = "password"
  url      = "https://10.1.1.1"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Optional

- `devices` (Attributes List) This can be used to manage a list of devices from a single provider. All devices must use the same credentials. Each resource and data source has an optional attribute named `device`, which can then select a device by its name from this list. (see [below for nested schema](#nestedatt--devices))
- `insecure` (Boolean) Allow insecure HTTPS client. This can also be set as the IOSXE_INSECURE environment variable. Defaults to `true`.
- `password` (String, Sensitive) Password for the IOS-XE device. This can also be set as the IOSXE_PASSWORD environment variable.
- `retries` (Number) Number of retries for REST API calls. This can also be set as the IOSXE_RETRIES environment variable. Defaults to `10`.
- `url` (String) URL of the Cisco IOS-XE device. Optionally a port can be added with `:12345`. The default port is `443`. This can also be set as the IOSXE_URL environment variable.
- `username` (String) Username for the IOS-XE device. This can also be set as the IOSXE_USERNAME environment variable.

<a id="nestedatt--devices"></a>
### Nested Schema for `devices`

Optional:

- `name` (String) Device name.
- `url` (String) URL of the Cisco IOS-XE device.