---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "iosxe_ospf Resource - terraform-provider-iosxe"
subcategory: "OSPF"
description: |-
  This resource can manage the OSPF configuration.
---

# iosxe_ospf (Resource)

This resource can manage the OSPF configuration.

## Example Usage

```terraform
resource "iosxe_ospf" "example" {
  process_id                           = 1
  bfd_all_interfaces                   = true
  default_information_originate        = true
  default_information_originate_always = true
  default_metric                       = 21
  distance                             = 120
  domain_tag                           = 10
  mpls_ldp_autoconfig                  = true
  mpls_ldp_sync                        = true
  neighbor = [
    {
      ip       = "2.2.2.2"
      priority = 10
      cost     = 100
    }
  ]
  network = [
    {
      ip       = "3.3.3.0"
      wildcard = "0.0.0.255"
      area     = "0"
    }
  ]
  priority  = 100
  router_id = "1.2.3.4"
  shutdown  = false
  summary_address = [
    {
      ip   = "3.3.3.0"
      mask = "255.255.255.0"
    }
  ]
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `process_id` (Number) Process ID
  - Range: `1`-`65535`

### Optional

- `bfd_all_interfaces` (Boolean) Enable BFD on all interfaces
- `default_information_originate` (Boolean) Distribute a default route
- `default_information_originate_always` (Boolean) Always advertise default route
- `default_metric` (Number) Set metric of redistributed routes
  - Range: `1`-`16777214`
- `device` (String) A device name from the provider configuration.
- `distance` (Number) Administrative distance
  - Range: `1`-`255`
- `domain_tag` (Number) OSPF domain-tag
  - Range: `1`-`4294967295`
- `mpls_ldp_autoconfig` (Boolean) Configure LDP automatic configuration
- `mpls_ldp_sync` (Boolean) Configure LDP-IGP Synchronization
- `neighbor` (Attributes List) Specify a neighbor router (see [below for nested schema](#nestedatt--neighbor))
- `network` (Attributes List) Enable routing on an IP network (see [below for nested schema](#nestedatt--network))
- `priority` (Number) OSPF topology priority
  - Range: `0`-`127`
- `router_id` (String) Override configured router identifier (peers will reset)
- `shutdown` (Boolean) Shutdown the OSPF protocol under the current instance
- `summary_address` (Attributes List) Configure IP address summaries (see [below for nested schema](#nestedatt--summary_address))

### Read-Only

- `id` (String) The path of the object.

<a id="nestedatt--neighbor"></a>
### Nested Schema for `neighbor`

Optional:

- `cost` (Number) OSPF cost for point-to-multipoint neighbor
  - Range: `1`-`65535`
- `ip` (String) Neighbor address
- `priority` (Number) OSPF priority of non-broadcast neighbor
  - Range: `0`-`255`


<a id="nestedatt--network"></a>
### Nested Schema for `network`

Optional:

- `area` (String) Set the OSPF area ID
- `ip` (String) Network number
- `wildcard` (String) OSPF wild card bits


<a id="nestedatt--summary_address"></a>
### Nested Schema for `summary_address`

Optional:

- `ip` (String) IP summary address
- `mask` (String) Summary mask

## Import

Import is supported using the following syntax:

```shell
terraform import iosxe_ospf.example "Cisco-IOS-XE-native:native/router/Cisco-IOS-XE-ospf:router-ospf/ospf/process-id=1"
```
